class Polygon():
    def __init__(self):
        pass


class Regular3gon():
    def __init__(self):
        pass


class Regular4gon():
    def __init__(self):
        pass


class Regular5gon():
    def __init__(self):
        pass
